@@ -277,6 +277,19 @@ sub customers {
 
 See L<Business::GoCardless::Webhook::V2> for more information on Webhook operations.
 
+=head2 webhooks (B<pager>)
+
+Get a list of L<Business::GoCardless::Webhook::V2> objects.
+
+    my @webhooks = $GoCardless->webhooks
+
+=cut
+
+sub webhooks {
+    my ( $self,%filters ) = @_;
+    return $self->_list( 'webhooks',\%filters );
+}
+
 =head2 webhook
 
 Get a L<Business::GoCardless::Webhook::V2> object from the data sent to you via a
@@ -323,6 +336,7 @@ sub _list {
         redirect_flows => 'RedirectFlow',
         customers      => 'Customer',
         subscriptions  => 'Subscription',
+        webhooks       => 'Webhook::V2',
     }->{ $endpoint };
 
     $filters //= {};
@@ -336,8 +350,20 @@ sub _list {
     my ( $data,$links,$info ) = $self->client->api_get( $uri );
 
     $class = "Business::GoCardless::$class";
-    my @objects = map { $class->new( client => $self->client,%{ $_ } ) }
-        @{ $data->{$endpoint} };
+    my @objects = map { $class->new(
+        client => $self->client,
+
+        # webhooks come back with stringified JSON
+        # so we need to further decode that
+        $endpoint eq 'webhooks'
+            ? (
+                json => $_->{request_body},
+                # load ordering handled by setting _signature rather than signature
+                # signature will be set in the json trigger
+                _signature => $_->{request_headers}{'Webhook-Signature'}
+            )
+            : ( %{ $_ } )
+    ); } @{ $data->{$endpoint} };
 
     return wantarray ? ( @objects ) : Business::GoCardless::Paginator->new(
         class   => $class,
@@ -505,9 +531,7 @@ sub confirm_resource {
                 payments => {
                     amount   => $amount,
                     currency => $currency,
-                    links    => {
-                        mandate => $RedirectFlow->links->{mandate},
-                    },
+                    links    => $RedirectFlow->links // {},
                 },
             };
 
@@ -532,9 +556,7 @@ sub confirm_resource {
                     interval_unit => $int_unit,
                     interval      => $interval,
                     start_date    => $start_at,
-                    links => {
-                        mandate => $RedirectFlow->links->{mandate},
-                    },
+                    links         => $RedirectFlow->links // {},
                 },
             };
 
